@@ -18,11 +18,14 @@
 #ifndef MANIP_H_
 #define MANIP_H_
 
+// [[Rcpp::interfaces(r, cpp)]]
 #include <Rcpp.h>
+#include <string>
 
 Rcpp::CharacterVector icd9AddLeadingZeroes(Rcpp::CharacterVector icd9, bool isShort);
 Rcpp::CharacterVector icd9AddLeadingZeroesShort(Rcpp::CharacterVector icd9Short);
 Rcpp::String icd9AddLeadingZeroesMajorSingle(Rcpp::String major);
+std::string icd9AddLeadingZeroesMajorSingleStd(std::string m);
 Rcpp::CharacterVector icd9AddLeadingZeroesMajor(Rcpp::CharacterVector major);
 
 #endif /* MANIP_H_ */
