@@ -24,4 +24,4 @@ if (identical(Sys.getenv("COVR"), "true")) {
   do_slow_tests <- TRUE
   do_online_tests <- TRUE
 }
-test_check("icd9", reporter = MultiReporter(reporters = list(SummaryReporter(), StopReporter())))
+test_check("icd9")
