@@ -46,7 +46,7 @@ test_that("elix comorbidity mapping is applied correctly,
             res <- icd9ComorbidElix(elixTestDat, isShort = TRUE,
                                     abbrevNames = FALSE,
                                     applyHierarchy = TRUE, return.df = TRUE)
-            expect_equal(dim(res), c(1,31))
+            expect_equal(dim(res), c(1, 31))
             expect_true(setequal(c("visitId", elixComorbidNames), names(res)))
             # should not have dm and dmcx, etc
             expect_false(all(as.logical(res[1, unlist(elixComorbidNames)])))
@@ -57,7 +57,7 @@ test_that("elix comorbidity mapping is applied correctly,
             res <- icd9ComorbidElix(elixTestDat, isShort = TRUE,
                                     abbrevNames = FALSE,
                                     applyHierarchy = TRUE, return.df = FALSE)
-            expect_equal(dim(res), c(1,30))
+            expect_equal(dim(res), c(1, 30))
             expect_true(setequal(elixComorbidNames, colnames(res)))
             # should not have dm and dmcx, etc
             expect_false(all(as.logical(res[1, unlist(elixComorbidNames)])))
@@ -71,7 +71,7 @@ test_that("elix comorbidity mapping is applied correctly,
                                     isShort = TRUE,
                                     abbrevNames = TRUE,
                                     applyHierarchy = TRUE, return.df = TRUE)
-            expect_equal(dim(res), c(1,31))
+            expect_equal(dim(res), c(1, 31))
             expect_true(setequal(c("visitId", elixComorbidNamesAbbrev), names(res)))
             # should not have dm and dmcx, etc
             expect_false(
@@ -84,7 +84,7 @@ test_that("elix comorbidity mapping is applied correctly,
                                     isShort = TRUE,
                                     abbrevNames = TRUE,
                                     applyHierarchy = TRUE, return.df = FALSE)
-            expect_equal(dim(res), c(1,30))
+            expect_equal(dim(res), c(1, 30))
             expect_true(setequal(elixComorbidNamesAbbrev, colnames(res)))
             # should not have dm and dmcx, etc
             expect_false(
@@ -98,7 +98,7 @@ test_that("elix comorbidity mapping is applied correctly,
             res <- icd9ComorbidElix(elixTestDat, isShort = TRUE,
                                     abbrevNames = FALSE,
                                     applyHierarchy = FALSE, return.df = TRUE)
-            expect_equal(dim(res), c(1,32)) #longer because 2x htn
+            expect_equal(dim(res), c(1, 32)) #longer because 2x htn
             expect_true(setequal(c("visitId", elixComorbidNamesHtn), names(res)))
             # not applying hierarchy, so dm and dmcx can both be true
             expect_true(all(as.logical(res[1, unlist(elixComorbidNamesHtn)])))
@@ -118,7 +118,7 @@ test_that("elix comorbidity mapping is applied correctly,
             res <- icd9ComorbidElix(elixTestDat, isShort = TRUE,
                                     abbrevNames = TRUE,
                                     applyHierarchy = FALSE, return.df = TRUE)
-            expect_equal(dim(res), c(1,32))
+            expect_equal(dim(res), c(1, 32))
             expect_true(setequal(c("visitId", elixComorbidNamesHtnAbbrev), names(res)))
             expect_true(
               all(as.logical(res[1, unlist(elixComorbidNamesHtnAbbrev)])))
@@ -127,7 +127,7 @@ test_that("elix comorbidity mapping is applied correctly,
             res <- icd9ComorbidElix(elixTestDat, isShort = TRUE,
                                     abbrevNames = TRUE,
                                     applyHierarchy = FALSE, return.df = FALSE)
-            expect_equal(dim(res), c(1,31))
+            expect_equal(dim(res), c(1, 31))
             expect_true(setequal(elixComorbidNamesHtnAbbrev, colnames(res)))
             expect_true(
               all(as.logical(res[1, unlist(elixComorbidNamesHtnAbbrev)])))
@@ -140,7 +140,7 @@ test_that("qelix comorbidity mapping is applied correctly,
                                         isShort = TRUE,
                                         abbrevNames = FALSE,
                                         applyHierarchy = TRUE, return.df = TRUE)
-            expect_equal(dim(res), c(1,31))
+            expect_equal(dim(res), c(1, 31))
             expect_true(setequal(c("visitId", quanElixComorbidNames), names(res)))
             # should not have dm and dmcx, etc
             expect_false(
@@ -153,7 +153,7 @@ test_that("qelix comorbidity mapping is applied correctly,
                                         isShort = TRUE,
                                         abbrevNames = FALSE,
                                         applyHierarchy = TRUE, return.df = FALSE)
-            expect_equal(dim(res), c(1,30))
+            expect_equal(dim(res), c(1, 30))
             expect_true(setequal(quanElixComorbidNames, colnames(res)))
             # should not have dm and dmcx, etc
             expect_false(
@@ -168,7 +168,7 @@ test_that("qelix comorbidity mapping is applied correctly,
                                         isShort = TRUE,
                                         abbrevNames = TRUE,
                                         applyHierarchy = TRUE, return.df = TRUE)
-            expect_equal(dim(res), c(1,31))
+            expect_equal(dim(res), c(1, 31))
             expect_true(setequal(c("visitId", quanElixComorbidNamesAbbrev), colnames(res)))
             # should not have dm and dmcx, etc
             expect_false(
@@ -198,7 +198,7 @@ test_that("qelix comorbidity mapping is applied correctly,
                                         abbrevNames = FALSE,
                                         applyHierarchy = FALSE, return.df = TRUE)
             #longer because 2x htn
-            expect_equal(dim(res), c(1,32))
+            expect_equal(dim(res), c(1, 32))
             # not applying hierarchy, so dm and dmcx can both be true
             expect_true(setequal(c("visitId", quanElixComorbidNamesHtn), names(res)))
             expect_true(
@@ -209,7 +209,7 @@ test_that("qelix comorbidity mapping is applied correctly,
                                         isShort = TRUE,
                                         abbrevNames = FALSE,
                                         applyHierarchy = FALSE, return.df = FALSE)
-            expect_equal(dim(res), c(1,31))
+            expect_equal(dim(res), c(1, 31))
             # not applying hierarchy, so dm and dmcx can both be true
             expect_true(setequal(quanElixComorbidNamesHtn, colnames(res)))
             expect_true(
@@ -222,7 +222,7 @@ test_that("qelix comorbidity mapping is applied correctly,
                                         isShort = TRUE,
                                         abbrevNames = TRUE,
                                         applyHierarchy = FALSE, return.df = TRUE)
-            expect_equal(dim(res), c(1,32))
+            expect_equal(dim(res), c(1, 32))
             expect_true(setequal(c("visitId", quanElixComorbidNamesHtnAbbrev), names(res)))
             expect_true(
               all(as.logical(res[1, unlist(quanElixComorbidNamesHtnAbbrev)])))
@@ -231,7 +231,7 @@ test_that("qelix comorbidity mapping is applied correctly,
                                         isShort = TRUE,
                                         abbrevNames = TRUE,
                                         applyHierarchy = FALSE, return.df = FALSE)
-            expect_equal(dim(res), c(1,31))
+            expect_equal(dim(res), c(1, 31))
             expect_true(setequal(quanElixComorbidNamesHtnAbbrev, colnames(res)))
             expect_true(
               all(as.logical(res[1, unlist(quanElixComorbidNamesHtnAbbrev)])))
@@ -254,7 +254,7 @@ test_that("ahrq comorbidity mapping is applied correctly,
             res <- icd9ComorbidAhrq(ahrqTestDat, isShort = TRUE,
                                     abbrevNames = TRUE,
                                     applyHierarchy = TRUE, return.df = FALSE)
-            expect_equal(dim(res), c(1,29))
+            expect_equal(dim(res), c(1, 29))
             expect_true(setequal(ahrqComorbidNamesAbbrev, colnames(res)))
             expect_false(
               all(as.logical(res[1, unlist(ahrqComorbidNamesAbbrev)])))
@@ -287,7 +287,7 @@ test_that("ahrq comorbidity mapping is applied correctly,
             res <- icd9ComorbidAhrq(ahrqTestDat, isShort = TRUE,
                                     abbrevNames = TRUE,
                                     applyHierarchy = FALSE, return.df = TRUE)
-            expect_equal(dim(res), c(1,31))
+            expect_equal(dim(res), c(1, 31))
             expect_true(setequal(c("visitId", ahrqComorbidNamesHtnAbbrev), names(res)))
             expect_true(
               all(as.logical(res[1, unlist(ahrqComorbidNamesHtnAbbrev)])))
@@ -326,11 +326,9 @@ test_that("get Charlson/Deyo comorbidities for a single patient", {
   mydf <- data.frame(visitId = c("a", "a"),
                      icd9 = c("044.9", "044.9"),
                      stringsAsFactors = FALSE)
-  expect_that(icd9ComorbidQuanDeyo(mydf, isShort = FALSE, return.df = TRUE),
-              testthat::not(throws_error()))
+  expect_error(icd9ComorbidQuanDeyo(mydf, isShort = FALSE, return.df = TRUE), NA)
 
   mydf <- data.frame(visitId = c("a", "a"), icd9 = c("441", "412.93"))
-  expect_that(icd9ComorbidQuanDeyo(mydf, isShort = FALSE, return.df = TRUE),
-              testthat::not(throws_error()))
+  expect_error(icd9ComorbidQuanDeyo(mydf, isShort = FALSE, return.df = TRUE), NA)
 
 })
